==> core-1.23.0-sources.jar: software/amazon/awscdk/core/Tokenization.java <==
package software.amazon.awscdk.core;

/**
 * Less oft-needed functions to manipulate Tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:48.124Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Tokenization")
public class Tokenization extends software.amazon.jsii.JsiiObject {

    protected Tokenization(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tokenization(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return whether the given object is an IResolvable object.
     * <p>
     * This is different from Token.isUnresolved() which will also check for
     * encoded Tokens, whereas this method will only do a type check on the given
     * object.
     * <p>
     * @param obj This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isResolvable(final java.lang.Object obj) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "isResolvable", java.lang.Boolean.class, new Object[] { obj });
    }

    /**
     * Resolves an object by evaluating all tokens and removing any undefined or empty objects or arrays.
     * <p>
     * Values can only be primitives, arrays or tokens. Other objects (i.e. with methods) will be rejected.
     * <p>
     * @param obj The object to resolve. This parameter is required.
     * @param options Prefix key path components for diagnostics. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Object resolve(final java.lang.Object obj, final software.amazon.awscdk.core.ResolveOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "resolve", java.lang.Object.class, new Object[] { obj, java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * Un-encode a Tokenized value from a list.
     * <p>
     * @param l This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseList(final java.util.List<java.lang.String> l) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseList", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(l, "l is required") });
    }

    /**
     * Un-encode a Tokenized value from a number.
     * <p>
     * @param n This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseNumber(final java.lang.Number n) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseNumber", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(n, "n is required") });
    }

    /**
     * Un-encode a string potentially containing encoded tokens.
     * <p>
     * @param s This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.TokenizedStringFragments reverseString(final java.lang.String s) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseString", software.amazon.awscdk.core.TokenizedStringFragments.class, new Object[] { java.util.Objects.requireNonNull(s, "s is required") });
    }

    /**
     * Stringify a number directly or lazily if it's a Token.
     * <p>
     * If it is an object (i.e., { Ref: 'SomeLogicalId' }), return it as-is.
     * <p>
     * @param x This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.String stringifyNumber(final java.lang.Number x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "stringifyNumber", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(x, "x is required") });
    }
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/Tokenization.java <==
package software.amazon.awscdk.core;

/**
 * Less oft-needed functions to manipulate Tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:49.801Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Tokenization")
public class Tokenization extends software.amazon.jsii.JsiiObject {

    protected Tokenization(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tokenization(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return whether the given object is an IResolvable object.
     * <p>
     * This is different from Token.isUnresolved() which will also check for
     * encoded Tokens, whereas this method will only do a type check on the given
     * object.
     * <p>
     * @param obj This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.Boolean isResolvable(final @org.jetbrains.annotations.NotNull java.lang.Object obj) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "isResolvable", java.lang.Boolean.class, new Object[] { obj });
    }

    /**
     * Resolves an object by evaluating all tokens and removing any undefined or empty objects or arrays.
     * <p>
     * Values can only be primitives, arrays or tokens. Other objects (i.e. with methods) will be rejected.
     * <p>
     * @param obj The object to resolve. This parameter is required.
     * @param options Prefix key path components for diagnostics. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.Object resolve(final @org.jetbrains.annotations.NotNull java.lang.Object obj, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ResolveOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "resolve", java.lang.Object.class, new Object[] { obj, java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * Un-encode a Tokenized value from a list.
     * <p>
     * @param l This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.IResolvable reverseList(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> l) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseList", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(l, "l is required") });
    }

    /**
     * Un-encode a Tokenized value from a number.
     * <p>
     * @param n This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.IResolvable reverseNumber(final @org.jetbrains.annotations.NotNull java.lang.Number n) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseNumber", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(n, "n is required") });
    }

    /**
     * Un-encode a string potentially containing encoded tokens.
     * <p>
     * @param s This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.TokenizedStringFragments reverseString(final @org.jetbrains.annotations.NotNull java.lang.String s) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseString", software.amazon.awscdk.core.TokenizedStringFragments.class, new Object[] { java.util.Objects.requireNonNull(s, "s is required") });
    }

    /**
     * Stringify a number directly or lazily if it's a Token.
     * <p>
     * If it is an object (i.e., { Ref: 'SomeLogicalId' }), return it as-is.
     * <p>
     * @param x This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String stringifyNumber(final @org.jetbrains.annotations.NotNull java.lang.Number x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "stringifyNumber", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(x, "x is required") });
    }
}
